---
Title: "Power Bpy - Function Reference"
include-before-body:
 text: |
  <script>document.title = "Power Bpy - Function Reference";</script>
---

# Methods reference {.doc .doc-index}

## Power Bpy

The first thing you should do is create an instance of the Dashboard class. Then use the `add_page()` or `load_page()` methods to attach instances of the internal `_Page` class to the dashboard you just created. All methods are attached to either dashboards or pages. Click below to see which methods are attached to which. For more details about how to build dashboards, see the test dashboard [tutorial](https://www.russellshean.com/powerbpy/example_dashboards/Test%20Dashboard/Testing%20Dashboard.html) section of this website.

| | |
| --- | --- |
| [dashboard](dashboard.qmd#powerbpy.dashboard) | A python class used to model a power BI dashboard project |
| [page._Page](page._Page.qmd#powerbpy.page._Page) | A python class used to model a power BI dashboard page. |